--- src/lib/yajl/Callbacks.hxx.orig	2025-01-29 16:11:53 UTC
+++ src/lib/yajl/Callbacks.hxx
@@ -32,7 +32,7 @@
 #include "util/Cast.hxx"
 #include "util/StringView.hxx"
 
-#include <yajl_parse.h>
+#include <yajl/yajl_parse.h>
 
 namespace Yajl {
 
