--- src/pcmanx_gtk2.cpp.orig	2016-02-16 12:31:46 UTC
+++ src/pcmanx_gtk2.cpp
@@ -35,6 +35,8 @@
 #include <cstring>
 #include <ltdl.h>
 
+#include <libintl.h> 
+
 #include "mainframe.h"
 #include "appconfig.h"
 #include "telnetcon.h"
