--- setup.py.orig	2015-10-12 21:38:11 UTC
+++ setup.py
@@ -9,7 +9,7 @@ setup(
     long_description = f.read()
 
 setup(
-    name='HoroscopeGenerator',
+    name='horoscopegenerator', 
     version='0.1.8',
 
     description='Generates horoscopes',
