--- src/diagnostics/view/diagnosticspathsmodel.cpp.orig	2023-07-14 10:17:41 UTC
+++ src/diagnostics/view/diagnosticspathsmodel.cpp
@@ -19,6 +19,8 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
+#include <QUrl>
+
 #include "diagnosticspathsmodel.h"
 
 #include "log.h"
