--- mysqltuner.pl.orig	2024-03-14 16:58:27 UTC
+++ mysqltuner.pl
@@ -1,3 +1,4 @@
+#!/usr/local/bin/perl
 # mysqltuner.pl - Version 2.5.2
 # High Performance MySQL Tuning Script
 # Copyright (C) 2015-2023 Jean-Marie Renouard - jmrenouard@gmail.com
