--- src/fr-command-7z.c.orig	2021-05-01 19:02:13 UTC
+++ src/fr-command-7z.c
@@ -325,8 +325,11 @@ fr_command_7z_add (FrCommand  *command,
 	fr_process_add_arg (command->process, "-bd");
 	fr_process_add_arg (command->process, "-bb1");
 	fr_process_add_arg (command->process, "-y");
-	if (follow_links)
-		fr_process_add_arg (command->process, "-l");
+	if (! follow_links)
+        {
+		fr_process_add_arg (command->process, "-snh");
+		fr_process_add_arg (command->process, "-snl");
+        }
 	add_password_arg (command, archive->password, FALSE);
 	if ((archive->password != NULL)
 	    && (*archive->password != 0)
