--- src/gain.c.orig	2000-10-28 11:45:51 UTC
+++ src/gain.c
@@ -3,7 +3,6 @@
 #endif
 #include <stdio.h>
 #include <math.h>
-#include <malloc.h>
 #include <errno.h>
 #include "yagi.h"
 #define TINY 1e-10
