--- bhmusers.cpp.orig	2008-04-10 01:36:27 UTC
+++ bhmusers.cpp
@@ -1,5 +1,6 @@
 #include "bhmusers.h"
-#include <stdio.h>
+#include <cstdio>
+#include <cstdlib>
 #include <cstring>
 #include "expand.h"
 
