--- gr-qtgui/include/gnuradio/qtgui/qtgui_types.h.orig	2024-02-19 05:18:00 UTC
+++ gr-qtgui/include/gnuradio/qtgui/qtgui_types.h
@@ -26,6 +26,7 @@
 #include <gnuradio/high_res_timer.h>
 #include <qwt_color_map.h>
 #include <qwt_scale_draw.h>
+#include <qwt_text.h>
 
 namespace gr {
 namespace qtgui {
