--- src/Gui/SoFCUnifiedSelection.h.orig	2023-01-21 23:07:09.710205000 +0100
+++ src/Gui/SoFCUnifiedSelection.h	2023-01-21 23:07:38.508972000 +0100
@@ -23,6 +23,7 @@
 #ifndef GUI_SOFCUNIFIEDSELECTION_H
 #define GUI_SOFCUNIFIEDSELECTION_H
 
+#include <array>
 #include <list>
 #include <unordered_map>
 #include <unordered_set>
