--- framework/base/stringutilities.cpp.orig	2005-05-07 14:40:24 UTC
+++ framework/base/stringutilities.cpp
@@ -3,6 +3,7 @@
 
 #include <algorithm>
 #include <stdlib.h>
+#include <cstring>
 #include <errno.h>
 
 #include "Report.h"
