--- src/particlecreation.h.orig	2020-12-10 05:08:02 UTC
+++ src/particlecreation.h
@@ -34,7 +34,7 @@
 // edge = 2 Upper edge
 // edge = 3 Left edge
 
-inline
+//inline
 void
 creation(int i,real t,int edge)
 {
