--- src/misc/newinstall.cxx.orig	2022-04-30 02:29:49 UTC
+++ src/misc/newinstall.cxx
@@ -67,7 +67,7 @@ text[4] = "\n\
 
 label[4] = "SK @||";
 text[4] = "\n\
-tnx fer QSO <NAME>, 73, God bless.\n\
+tnx fer QSO <NAME>, 73.\n\
 <ZDT> <CALL> de <MYCALL> sk\n\
 <RX>";
 
