--- src/lib/yajl/Gen.hxx.orig	2025-01-29 16:11:53 UTC
+++ src/lib/yajl/Gen.hxx
@@ -31,7 +31,7 @@
 
 #include "util/ConstBuffer.hxx"
 
-#include <yajl_gen.h>
+#include <yajl/yajl_gen.h>
 
 #include <algorithm>
 #include <string_view>
