--- gdsStream.h.orig	2014-12-08 17:16:44 UTC
+++ gdsStream.h
@@ -4,8 +4,7 @@
 #define _gdsStream__
 
 #include <stdio.h>
-#include <malloc.h>
-#include <stdio.h>
+#include <stdlib.h>
 #include <time.h>
 #include <kvstypes.h>
 
