--- src/lib/yajl/Handle.hxx.orig	2025-01-29 16:11:53 UTC
+++ src/lib/yajl/Handle.hxx
@@ -29,7 +29,7 @@
 
 #pragma once
 
-#include <yajl_parse.h>
+#include <yajl/yajl_parse.h>
 
 #include <utility>
 
