--- tests/fff_print/test_data.cpp.orig	2023-07-25 13:20:52 UTC
+++ tests/fff_print/test_data.cpp
@@ -8,6 +8,7 @@
 #include "libslic3r/Format/STL.hpp"
 
 #include <cstdlib>
+#include <fstream>
 #include <string>
 
 #include <boost/nowide/cstdio.hpp>
