--- src/learn/view/learnpagemodel.h.orig	2023-07-14 10:22:05 UTC
+++ src/learn/view/learnpagemodel.h
@@ -23,6 +23,8 @@
 #define MU_LEARN_LEARNPAGEMODEL_H
 
 #include <QObject>
+#include <QVariantMap>
+#include <QString>
 
 #include "async/asyncable.h"
 
