--- app/src/usb/aoa_hid.h.orig	2024-12-04 21:48:27 UTC
+++ app/src/usb/aoa_hid.h
@@ -6,7 +6,7 @@
 #include <stdint.h>
 #include <stdbool.h>
 
-#include <libusb-1.0/libusb.h>
+#include <libusb.h>
 
 #include "hid/hid_event.h"
 #include "usb.h"
