--- src/qmapshack/map/CMapIMG.cpp.orig	2021-05-24 09:18:08 UTC
+++ src/qmapshack/map/CMapIMG.cpp
@@ -34,6 +34,7 @@
 
 #include <QPainterPath>
 #include <QtWidgets>
+#include <QPainterPath>
 
 #undef DEBUG_SHOW_SECT_DESC
 #undef DEBUG_SHOW_TRE_DATA
