--- modules/gst/gst.c.orig	2021-04-21 09:34:08 UTC
+++ modules/gst/gst.c
@@ -4,7 +4,7 @@
  * Copyright (C) 2010 - 2015 Alfred E. Heggestad
  */
 #define _DEFAULT_SOURCE 1
-#define _POSIX_C_SOURCE 199309L
+#define _POSIX_C_SOURCE 200112L
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
